==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/fa-IR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'لوازم جانبی بررسی شد',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'دارایی ثبت شد
',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'تأیید ورود لوازم جانبی',
    'Confirm_Asset_Checkin' => 'تأیید ورود دارایی
',
    'Confirm_accessory_delivery' => 'تاییدیه تحویل لوازم جانبی',
    'Confirm_asset_delivery' => 'تاییدیه تحویل دارایی
',
    'Confirm_consumable_delivery' => 'تاییدیه تحویل مصرفی
',
    'Confirm_license_delivery' => 'تاییدیه تحویل مجوز
',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'روزها',
    'Expected_Checkin_Date' => 'دارایی‌ای که برای شما بررسی شده است باید دوباره در تاریخ :date بررسی شود',
    'Expected_Checkin_Notification' => 'یادآوری: :نام مهلت اعلام حضور نزدیک است
',
    'Expected_Checkin_Report' => 'گزارش بررسی دارایی مورد انتظار
',
    'Expiring_Assets_Report' => 'گزارش دارایی های معوق',
    'Expiring_Licenses_Report' => 'گزارش مجوزهای منقضی شده',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'License_Checkin_Notification' => 'مجوز بررسی شد
',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'نام وسیله',
    'additional_notes' => 'یادداشت های اضافی',
    'admin_has_created' => 'یک مدیر یک حساب کاربری برای شما در وب سایت وب ایجاد کرده است.',
    'asset' => 'دارایی',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'نام دارایی',
    'assets_warrantee_alert' => 'دارایی :count با گارانتی منقضی در روزهای بعدی: آستانه وجود دارد.',
    'assigned_to' => 'اختصاص یافته به',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد',
    'checkin_date' => 'تاریخ ورود
',
    'checkout_date' => 'چک کردن تاریخ',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'current_QTY' => 'QTY فعلی',
    'days' => 'روزها',
    'expecting_checkin_date' => ' چک در تاریخ را پر کنید',
    'expires' => 'منقضی می شود',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'inventory_report' => 'Inventory Report',
    'item' => 'مورد',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'مجوز :count در روزهای بعدی :threshold منقضی می شود.|مجوزهای :count در روزهای بعدی :threshold منقضی می شوند.',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login' => 'ورود',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'low_inventory_alert' => 'آیتم :count وجود دارد که زیر حداقل موجودی است یا به زودی کم می شود.',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'یک آیتم جدید تحت نام شما چک شده است، جزئیات زیر است.',
    'notes' => 'نت ها',
    'password' => 'رمز عبور',
    'password_reset' => 'تنظیم مجدد رمز عبور',
    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'در خواست شده',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'سریال',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'دارایی :count وجود دارد که در روزهای :threshold برای حسابرسی ارائه می شود.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_assets' => 'دارایی های خود را مشاهده کنید
',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fa-IR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'لوازم جانبی بررسی شد',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'تأیید ورود لوازم جانبی',
    'Confirm_Asset_Checkin' => 'تأیید ورود دارایی
',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'تاییدیه تحویل لوازم جانبی',
    'Confirm_asset_delivery' => 'تاییدیه تحویل دارایی
',
    'Confirm_consumable_delivery' => 'تاییدیه تحویل مصرفی
',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'تاییدیه تحویل مجوز
',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'روزها',
    'Expected_Checkin_Date' => 'دارایی‌ای که برای شما بررسی شده است باید دوباره در تاریخ :date بررسی شود',
    'Expected_Checkin_Notification' => 'یادآوری: :نام مهلت اعلام حضور نزدیک است
',
    'Expected_Checkin_Report' => 'گزارش بررسی دارایی مورد انتظار
',
    'Expiring_Assets_Report' => 'Expiring Assets Report',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report',
    'Item_Request_Canceled' => 'درخواست مورد لغو شد',
    'Item_Requested' => 'مورد درخواست شده',
    'License_Checkin_Notification' => 'مجوز بررسی شد
',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'گزارش موجودی کم',
    'a_user_canceled' => 'یک کاربر یک درخواست اقساط در وب سایت را لغو کرده است',
    'a_user_requested' => 'یک کاربر یک مورد را در وبسایت درخواست کرده است',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'نام وسیله',
    'additional_notes' => 'یادداشت های اضافی',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'دارایی',
    'asset_name' => 'نام دارایی',
    'asset_requested' => 'دارایی درخواست شد',
    'asset_tag' => 'نام دارایی',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'اختصاص یافته به',
    'eol' => 'EOL',
    'best_regards' => 'با احترام،',
    'canceled' => 'لغو شد',
    'checkin_date' => 'تاریخ ورود
',
    'checkout_date' => 'چک کردن تاریخ',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که لوازم جانبی را دریافت کرده اید.',
    'click_on_the_link_asset' => 'لطفا روی لینک زیر کلیک کنید تا تأیید کنید که دارایی را دریافت کرده اید.',
    'click_to_confirm' => 'لطفا برای پیوستن به این لینک کلیک کنید تا حساب خود را تایید کنید:',
    'current_QTY' => 'QTY فعلی',
    'days' => 'روزها',
    'expecting_checkin_date' => ' چک در تاریخ را پر کنید',
    'expires' => 'منقضی می شود',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'سلام',
    'hi' => 'سلام',
    'i_have_read' => 'من شرایط استفاده را خوانده ام و موافقم و این مورد را دریافت کرده ام.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Inventory Report',
    'item' => 'مورد',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'برای به روزرسانی لطفا بر روی لینک زیر کلیک کنید: web password:',
    'login' => 'ورود',
    'login_first_admin' => 'با نصب مجدد Snipe-IT جدید خود به سیستم وارد شوید',
    'low_inventory_alert' => 'آیتم :count وجود دارد که زیر حداقل موجودی است یا به زودی کم می شود.',
    'min_QTY' => 'حداقل QTY',
    'name' => 'نام',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'نت ها',
    'password' => 'رمز عبور',
    'password_reset' => 'تنظیم مجدد رمز عبور',
    'read_the_terms' => 'لطفا شرایط استفاده زیر را بخوانید.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'در خواست شده',
    'reset_link' => 'رمز عبور خود را بازنشانی کنید',
    'reset_password' => 'برای تغییر رمز عبور اینجا کلیک کنید:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'سریال',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'تامین کننده',
    'tag' => 'برچسب',
    'test_email' => 'ایمیل تست از Snipe-IT',
    'test_mail_text' => 'این آزمون از سیستم مدیریت دارایی Snipe-IT است. اگر شما این کار را کردید، ایمیل کار می کند :)',
    'the_following_item' => 'مورد زیر مورد بررسی قرار گرفته است:',
    'to_reset' => 'برای بازنشانی: رمز عبور وب، این فرم را تکمیل کنید:',
    'type' => 'تایپ کنید',
    'upcoming-audits' => 'دارایی :count وجود دارد که در روزهای :threshold برای حسابرسی ارائه می شود.',
    'user' => 'کاربر',
    'username' => 'نام کاربری',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'خوش آمدید نام',
    'welcome_to' => 'به وب سایت خوش آمدید',
    'your_assets' => 'دارایی های خود را مشاهده کنید
',
    'your_credentials' => 'مدارک Snipe-IT شما',
    'mail_sent' => 'Mail sent successfully!',
];
